import { Observable } from '@reactivex/rxjs';
export declare namespace ErrorMessage {
    /**
     * schema for specific error cause
     */
    interface ErrorDetail {
        /**
         * a bean notation expression specifying the element in request data causing the error, eg product.variants[3].name, this can be empty if violation was not field specific
         */
        field?: string;
        /**
         * classification of the error detail type, lower case with underscore eg missing_value, this value must be always interpreted in context of the general error type.
         */
        type: string;
        /**
         * descriptive error detail message for debugging
         */
        message?: string;
        /**
         * link to documentation to investigate further and finding support for error detail
         */
        moreInfo?: string;
        [k: string]: any;
    }
    /**
     * Schema for API specified errors.
     */
    interface ErrorMessage {
        /**
         * original HTTP error code, should be consistent with the response HTTP code
         */
        status: number;
        /**
         * classification of the error type, lower case with underscore eg validation_failure
         */
        type: string;
        /**
         * descriptive error message for debugging
         */
        message?: string;
        /**
         * link to documentation to investigate further and finding support
         */
        moreInfo?: string;
        /**
         * list of problems causing this error
         */
        details?: ErrorDetail[];
        [k: string]: any;
    }
}
export declare namespace Yrn {
    type Yrn = string;
}
export declare namespace MediaMetadata {
    type YrnAttribute = string;
    /**
     * Media file metadata
     */
    interface MediaMetadata {
        id?: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn?: YrnAttribute;
        /**
         * ISO 8601 format date in which the media metadata was created.
         */
        createdAt?: string;
        /**
         * URL of file content
         */
        url?: string;
        /**
         * Media file tags
         */
        tags?: string[];
        /**
         * MIME type of the media file
         */
        contentType?: string;
        /**
         * Link on which user should upload (PUT) media file.
         */
        uploadLink?: string;
        /**
         * If true, the media file is not committed yet. If property is set to false or is not present the media is already committed
         */
        uncommittedMedia?: boolean;
        /**
         * Map of custom attributes. The map key is a string, the value can be any JSON object
         */
        customAttributes?: any;
    }
}
export declare namespace MediaMetadataCollection {
    type YrnAttribute = string;
    type MediaMetadataCollection = {
        id?: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn?: YrnAttribute;
        /**
         * ISO 8601 format date in which the media metadata was created.
         */
        createdAt?: string;
        /**
         * URL of file content
         */
        url?: string;
        /**
         * Media file tags
         */
        tags?: string[];
        /**
         * MIME type of the media file
         */
        contentType?: string;
        /**
         * Link on which user should upload (PUT) media file.
         */
        uploadLink?: string;
        /**
         * If true, the media file is not committed yet. If property is set to false or is not present the media is already committed
         */
        uncommittedMedia?: boolean;
        /**
         * Map of custom attributes. The map key is a string, the value can be any JSON object
         */
        customAttributes?: any;
    }[];
}
export declare namespace MediaMetadataCreation {
    /**
     * Media file metadata
     */
    interface MediaMetadataCreation {
        /**
         * Media file tags
         */
        tags?: string[];
        /**
         * Media order is set based on position property. Position is indexed from 0. If value is <= 0 the media is ordered as first. If value is higher that media count or is not specified the media is ordered as last. When retrieving product media they are ordered, but position property is not returned as it is not persisted
         */
        position?: number;
        /**
         * MIME type of the file. The provided content type should be the same as the Content-Type header provided during media update, otherwise the update will fail
         */
        contentType: string;
        /**
         * Map of custom attributes. The map key should be a string, the value can be any JSON object
         */
        customAttributes?: any;
    }
}
export declare namespace MediaMetadataUpdate {
    /**
     * Schema to update media file metadata
     */
    interface MediaMetadataUpdate {
        /**
         * Media file tags
         */
        tags?: string[];
        /**
         * Media order is set based on position property. Position is indexed from 0. If value is <= 0 the media is ordered as first. If value is higher that media count or is not specified the media is ordered as last. When retrieving product media they are ordered, but position property value is not returned as it is not persisted
         */
        position?: number;
        /**
         * Map of custom attributes. The map key should be a string, the value can be any JSON object
         */
        customAttributes?: any;
    }
}
export declare namespace ProductCreation {
    type Localized = any;
    interface ProductCreation {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            variants?: {
                options?: {
                    [k: string]: string;
                };
            };
        };
        /**
         * Unique identifier
         */
        id?: string;
        /**
         * Unique, mandatory user-defined identifier of a product
         */
        code: string;
        /**
         * The name of the product.
         */
        name: Localized;
        /**
         * The description of the product.
         */
        description?: Localized;
        /**
         * This flag determines if product is live.
         */
        published?: boolean;
        mixins?: Object;
    }
}
export declare namespace ProductUpdate {
    type Localized = any;
    interface ProductUpdate {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            variants?: {
                options?: {
                    [k: string]: string;
                };
            };
        };
        /**
         * Unique, mandatory user-defined identifier of a product
         */
        code: string;
        /**
         * The name of the product.
         */
        name: Localized;
        /**
         * The description of the product.
         */
        description?: Localized;
        /**
         * This flag determines if product is live.
         */
        published?: boolean;
        mixins?: Object;
    }
}
export declare namespace Product {
    type YrnAttribute = string;
    type Localized = any;
    interface Product {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            variants?: {
                options?: {
                    [k: string]: string;
                };
                mixins?: {
                    [k: string]: string;
                };
            };
            version?: number;
            /**
             * ISO 8601 format date in which the product was created.
             */
            createdAt?: string;
            /**
             * ISO 8601 format date in which the product was modified.
             */
            modifiedAt?: string;
        };
        /**
         * Unique identifier
         */
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        /**
         * Unique, mandatory user-defined identifier of a product
         */
        code?: string;
        /**
         * The name of the product.
         */
        name?: Localized;
        /**
         * The description of the product.
         */
        description?: Localized;
        /**
         * This flag determines if product is live.
         */
        published?: boolean;
        /**
         * Contains media information (including url). This attribute is Read-Only, to manage media collection please use the /media subresource. To get this attribute included in product please add the expand=media query param. By default this attribute is not returned with product.
         */
        media?: {
            id?: string;
            /**
             * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
             */
            yrn?: YrnAttribute;
            mediaId?: string;
            /**
             * URL of file content
             */
            url?: string;
            /**
             * Media file tags
             */
            tags?: string[];
            /**
             * MIME type of the media file
             */
            contentType?: string;
            /**
             * If true, the media file is stored in the service. Otherwise the service only stores external URL of the file and metadata.
             */
            stored?: boolean;
            /**
             * Date of media metadata creation.
             */
            createdAt?: string;
            /**
             * Contains link which is used when user triggers media commit operation. This link is not returned to user as product service internally triggers the commit
             */
            commitLink?: string;
            /**
             * Contains link on which user should send media for upload before he triggers the commit operation
             */
            uploadLink?: string;
            /**
             * If true, the media file is not committed yet. Not committed media does no have url property provided
             */
            uncommittedMedia?: boolean;
        }[];
        mixins?: Object;
    }
}
export declare namespace Products {
    type YrnAttribute = string;
    type Localized = any;
    type Products = {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            variants?: {
                options?: {
                    [k: string]: string;
                };
                mixins?: {
                    [k: string]: string;
                };
            };
            version?: number;
            /**
             * ISO 8601 format date in which the product was created.
             */
            createdAt?: string;
            /**
             * ISO 8601 format date in which the product was modified.
             */
            modifiedAt?: string;
        };
        /**
         * Unique identifier
         */
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        /**
         * Unique, mandatory user-defined identifier of a product
         */
        code?: string;
        /**
         * The name of the product.
         */
        name?: Localized;
        /**
         * The description of the product.
         */
        description?: Localized;
        /**
         * This flag determines if product is live.
         */
        published?: boolean;
        /**
         * Contains media information (including url). This attribute is Read-Only, to manage media collection please use the /media subresource. To get this attribute included in product please add the expand=media query param. By default this attribute is not returned with product.
         */
        media?: {
            id?: string;
            /**
             * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
             */
            yrn?: YrnAttribute;
            mediaId?: string;
            /**
             * URL of file content
             */
            url?: string;
            /**
             * Media file tags
             */
            tags?: string[];
            /**
             * MIME type of the media file
             */
            contentType?: string;
            /**
             * If true, the media file is stored in the service. Otherwise the service only stores external URL of the file and metadata.
             */
            stored?: boolean;
            /**
             * Date of media metadata creation.
             */
            createdAt?: string;
            /**
             * Contains link which is used when user triggers media commit operation. This link is not returned to user as product service internally triggers the commit
             */
            commitLink?: string;
            /**
             * Contains link on which user should send media for upload before he triggers the commit operation
             */
            uploadLink?: string;
            /**
             * If true, the media file is not committed yet. Not committed media does no have url property provided
             */
            uncommittedMedia?: boolean;
        }[];
        mixins?: Object;
    }[];
}
export declare namespace ResourceLocation {
    type YrnAttribute = string;
    interface ResourceLocation {
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        link: string;
        [k: string]: any;
    }
}
export declare namespace MediaLocation {
    type YrnAttribute = string;
    interface MediaLocation {
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        uploadLink: string;
        [k: string]: any;
    }
}
export declare namespace TenantAction {
    interface TenantAction {
        tenant: string;
        action: string;
        [k: string]: any;
    }
}
export declare namespace GenericResponse {
    interface GenericResponse {
        code: string;
        status?: string;
        message?: string;
        data?: string;
        [k: string]: any;
    }
}
export declare namespace ProductVariant {
    type YrnAttribute = string;
    type Localized = any;
    interface ProductVariant {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            version?: number;
            /**
             * ISO 8601 format date in which the product variant was created.
             */
            createdAt?: string;
            /**
             * ISO 8601 format date in which the product variant was modified.
             */
            modifiedAt?: string;
        };
        /**
         * Unique identifier
         */
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        /**
         * Unique, mandatory user-defined identifier of a product variant
         */
        code?: string;
        /**
         * The name of the product variant.
         */
        name?: Localized;
        options?: Object;
        /**
         * Contains media information (including url). This attribute is Read-Only, to manage media collection please use the /media subresource. To get this attribute included in product please add the expand=media query param. By default this attribute is not returned with product.
         */
        media?: {
            id?: string;
            /**
             * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
             */
            yrn?: YrnAttribute;
            mediaId?: string;
            /**
             * URL of file content
             */
            url?: string;
            /**
             * Media file tags
             */
            tags?: string[];
            /**
             * MIME type of the media file
             */
            contentType?: string;
            /**
             * If true, the media file is stored in the service. Otherwise the service only stores external URL of the file and metadata.
             */
            stored?: boolean;
            /**
             * Date of media metadata creation.
             */
            createdAt?: string;
            /**
             * Contains link which is used when user triggers media commit operation. This link is not returned to user as product service internally triggers the commit
             */
            commitLink?: string;
            /**
             * Contains link on which user should send media for upload before he triggers the commit operation
             */
            uploadLink?: string;
            /**
             * If true, the media file is not committed yet. Not committed media does no have url property provided
             */
            uncommittedMedia?: boolean;
        }[];
        mixins?: Object;
        /**
         * This flag determines if variant is a default variant.
         */
        default?: boolean;
    }
}
export declare namespace ProductVariantWithProduct {
    type YrnAttribute = string;
    type Localized = any;
    interface ProductVariantWithProduct {
        /**
         * Product identifier
         */
        productId?: string;
        /**
         * Unique identifier
         */
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        /**
         * Unique, mandatory user-defined identifier of a product variant
         */
        code?: string | null;
        /**
         * The name of the product variant.
         */
        name?: Localized;
        options?: Object;
        /**
         * This flag determines if variant is a default variant.
         */
        default?: boolean;
        product?: {
            metadata?: {
                mixins?: {
                    [k: string]: string;
                };
                variants?: {
                    options?: {
                        [k: string]: string;
                    };
                    mixins?: {
                        [k: string]: string;
                    };
                };
                version?: number;
                /**
                 * ISO 8601 format date in which the product was created.
                 */
                createdAt?: string;
                /**
                 * ISO 8601 format date in which the product was modified.
                 */
                modifiedAt?: string;
            };
            /**
             * Unique identifier
             */
            id: string;
            /**
             * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
             */
            yrn: YrnAttribute;
            /**
             * Unique, mandatory user-defined identifier of a product
             */
            code?: string;
            /**
             * The name of the product.
             */
            name?: Localized;
            /**
             * The description of the product.
             */
            description?: Localized;
            /**
             * This flag determines if product is live.
             */
            published?: boolean;
            /**
             * Contains media information (including url). This attribute is Read-Only, to manage media collection please use the /media subresource. To get this attribute included in product please add the expand=media query param. By default this attribute is not returned with product.
             */
            media?: {
                id?: string;
                /**
                 * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
                 */
                yrn?: YrnAttribute;
                mediaId?: string;
                /**
                 * URL of file content
                 */
                url?: string;
                /**
                 * Media file tags
                 */
                tags?: string[];
                /**
                 * MIME type of the media file
                 */
                contentType?: string;
                /**
                 * If true, the media file is stored in the service. Otherwise the service only stores external URL of the file and metadata.
                 */
                stored?: boolean;
                /**
                 * Date of media metadata creation.
                 */
                createdAt?: string;
                /**
                 * Contains link which is used when user triggers media commit operation. This link is not returned to user as product service internally triggers the commit
                 */
                commitLink?: string;
                /**
                 * Contains link on which user should send media for upload before he triggers the commit operation
                 */
                uploadLink?: string;
                /**
                 * If true, the media file is not committed yet. Not committed media does no have url property provided
                 */
                uncommittedMedia?: boolean;
            }[];
            mixins?: Object;
        };
    }
}
export declare namespace ProductVariants {
    type YrnAttribute = string;
    type Localized = any;
    type ProductVariants = {
        metadata?: {
            mixins?: {
                [k: string]: string;
            };
            version?: number;
            /**
             * ISO 8601 format date in which the product variant was created.
             */
            createdAt?: string;
            /**
             * ISO 8601 format date in which the product variant was modified.
             */
            modifiedAt?: string;
        };
        /**
         * Unique identifier
         */
        id: string;
        /**
         * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
         */
        yrn: YrnAttribute;
        /**
         * Unique, mandatory user-defined identifier of a product variant
         */
        code?: string;
        /**
         * The name of the product variant.
         */
        name?: Localized;
        options?: Object;
        /**
         * Contains media information (including url). This attribute is Read-Only, to manage media collection please use the /media subresource. To get this attribute included in product please add the expand=media query param. By default this attribute is not returned with product.
         */
        media?: {
            id?: string;
            /**
             * Contains the YaaS Resource Name (YRN) of a specific resource on base of the 'yaas' URN scheme
             */
            yrn?: YrnAttribute;
            mediaId?: string;
            /**
             * URL of file content
             */
            url?: string;
            /**
             * Media file tags
             */
            tags?: string[];
            /**
             * MIME type of the media file
             */
            contentType?: string;
            /**
             * If true, the media file is stored in the service. Otherwise the service only stores external URL of the file and metadata.
             */
            stored?: boolean;
            /**
             * Date of media metadata creation.
             */
            createdAt?: string;
            /**
             * Contains link which is used when user triggers media commit operation. This link is not returned to user as product service internally triggers the commit
             */
            commitLink?: string;
            /**
             * Contains link on which user should send media for upload before he triggers the commit operation
             */
            uploadLink?: string;
            /**
             * If true, the media file is not committed yet. Not committed media does no have url property provided
             */
            uncommittedMedia?: boolean;
        }[];
        mixins?: Object;
        /**
         * This flag determines if variant is a default variant.
         */
        default?: boolean;
    }[];
}
export declare namespace ProductVariantCreation {
    type Localized = any;
    interface ProductVariantCreation {
        /**
         * Unique, mandatory user-defined identifier of a product variant
         */
        code: string;
        /**
         * The name of the product variant.
         */
        name?: Localized;
        options?: Object;
        /**
         * This flag determines if variant is a default variant.
         */
        default?: boolean;
    }
}
export declare namespace ProductVariantUpdate {
    type Localized = any;
    interface ProductVariantUpdate {
        /**
         * Unique, mandatory user-defined identifier of a product variant
         */
        code: string;
        /**
         * The name of the product variant.
         */
        name?: Localized;
        options?: Object;
        /**
         * This flag determines if variant is a default variant.
         */
        default?: boolean;
    }
}
export declare namespace SearchQuery {
    type YrnAttribute = string;
    interface SearchQuery {
        /**
         * List of yrns. Each yrn identifies either product or product variant
         */
        yrns: YrnAttribute[];
        /**
         * Optional query params
         */
        params?: {
            /**
             * Optional query params for products
             */
            product?: {
                /**
                 * Optional projection for product
                 */
                fields?: string;
                [k: string]: any;
            };
            /**
             * Optional query params for product variant
             */
            variant?: {
                /**
                 * Optional projection for product variant
                 */
                fields?: string;
                /**
                 * Optional expand option for product variants
                 */
                expand?: "product";
                [k: string]: any;
            };
            [k: string]: any;
        };
    }
}
export declare namespace SearchQueryResult {
    type SearchQueryResult = any[];
}
export declare namespace NotEmptyLocalizedAttribute {
    type NotEmptyLocalizedAttribute = any;
}
export declare namespace NullableLocalizedAttribute {
    type NullableLocalizedAttribute = any;
}
export declare class YaasApiProductV2 {
    _client: any;
    _path: string;
    _options: any;
    _form: any;
    _version: any;
    _Security: any;
    constructor(options?: any);
    request(client: any, method: any, path: any, opts: any): any;
    tenant(tenant: string): Resources.Tenant;
}
export declare module Resources {
    class Tenant {
        _client: any;
        _path: string;
        products: Tenant.TenantProducts;
        constructor(client: any, path: any);
    }
    module Tenant {
        class TenantProducts {
            _client: any;
            _path: string;
            constructor(client: any, path: any);
            productId(productId: string): TenantProducts.TenantProductsProductId;
            /**
             * GET on TenantProducts
             */
            GET(fields?: string, q?: string, sort?: string, pageNumber?: number, pageSize?: number, opts?: any): Observable<{
                headers: any;
                responseCode: number;
                bodyRaw: any;
                "_200": any;
                "_400": any;
                "_401": any;
                "_403": any;
                "_500": any;
                "_503": any;
            }>;
            /**
             * POST on TenantProducts
             */
            POST(body: any, opts?: any): Observable<{
                headers: any;
                responseCode: number;
                bodyRaw: any;
                "_201": any;
                "_400": any;
                "_401": any;
                "_403": any;
                "_404": any;
                "_409": any;
                "_500": any;
                "_503": any;
            }>;
            /**
             * DELETE on TenantProducts
             */
            DELETE(opts?: any): Observable<{
                headers: any;
                responseCode: number;
                bodyRaw: any;
                "_204": any;
                "_401": any;
                "_403": any;
                "_500": any;
                "_503": any;
            }>;
        }
        module TenantProducts {
            class TenantProductsProductId {
                _client: any;
                _path: string;
                media: Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdMedia;
                constructor(client: any, path: any);
                /**
                 * GET on TenantProductsProductId
                 */
                GET(fields?: string, opts?: any): Observable<{
                    headers: any;
                    responseCode: number;
                    bodyRaw: any;
                    "_200": any;
                    "_400": any;
                    "_401": any;
                    "_403": any;
                    "_404": any;
                    "_500": any;
                    "_503": any;
                }>;
                /**
                 * PUT on TenantProductsProductId
                 */
                PUT(body: any, partial?: boolean, opts?: any): Observable<{
                    headers: any;
                    responseCode: number;
                    bodyRaw: any;
                    "_200": any;
                    "_400": any;
                    "_401": any;
                    "_403": any;
                    "_404": any;
                    "_409": any;
                    "_500": any;
                    "_503": any;
                }>;
                /**
                 * DELETE on TenantProductsProductId
                 */
                DELETE(opts?: any): Observable<{
                    headers: any;
                    responseCode: number;
                    bodyRaw: any;
                    "_204": any;
                    "_401": any;
                    "_403": any;
                    "_404": any;
                    "_500": any;
                    "_503": any;
                }>;
            }
            module TenantProductsProductId {
                class TenantProductsProductIdMedia {
                    _client: any;
                    _path: string;
                    constructor(client: any, path: any);
                    mediaId(mediaId: string): TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId;
                    /**
                     * POST on TenantProductsProductIdMedia
                     */
                    POST(body: any, opts?: any): Observable<{
                        headers: any;
                        responseCode: number;
                        bodyRaw: any;
                        "_200": any;
                        "_401": any;
                        "_403": any;
                        "_404": any;
                        "_500": any;
                        "_503": any;
                    }>;
                    /**
                     * GET on TenantProductsProductIdMedia
                     */
                    GET(opts?: any): Observable<{
                        headers: any;
                        responseCode: number;
                        bodyRaw: any;
                        "_200": any;
                        "_401": any;
                        "_403": any;
                        "_404": any;
                        "_500": any;
                        "_503": any;
                    }>;
                }
                module TenantProductsProductIdMedia {
                    class TenantProductsProductIdMediaMediaId {
                        _client: any;
                        _path: string;
                        commit: Tenant.TenantProducts.TenantProductsProductId.TenantProductsProductIdMedia.TenantProductsProductIdMediaMediaId.TenantProductsProductIdMediaMediaIdCommit;
                        constructor(client: any, path: any);
                        /**
                         * GET on TenantProductsProductIdMediaMediaId
                         */
                        GET(opts?: any): Observable<{
                            headers: any;
                            responseCode: number;
                            bodyRaw: any;
                            "_200": any;
                            "_401": any;
                            "_403": any;
                            "_404": any;
                            "_500": any;
                            "_503": any;
                        }>;
                        /**
                         * PUT on TenantProductsProductIdMediaMediaId
                         */
                        PUT(body: any, partial?: boolean, opts?: any): Observable<{
                            headers: any;
                            responseCode: number;
                            bodyRaw: any;
                            "_200": any;
                            "_400": any;
                            "_401": any;
                            "_403": any;
                            "_404": any;
                            "_409": any;
                            "_500": any;
                            "_503": any;
                        }>;
                        /**
                         * DELETE on TenantProductsProductIdMediaMediaId
                         */
                        DELETE(opts?: any): Observable<{
                            headers: any;
                            responseCode: number;
                            bodyRaw: any;
                            "_204": any;
                            "_401": any;
                            "_403": any;
                            "_404": any;
                            "_500": any;
                            "_503": any;
                        }>;
                    }
                    module TenantProductsProductIdMediaMediaId {
                        class TenantProductsProductIdMediaMediaIdCommit {
                            _client: any;
                            _path: string;
                            constructor(client: any, path: any);
                            /**
                             * POST on TenantProductsProductIdMediaMediaIdCommit
                             */
                            POST(opts?: any): Observable<{
                                headers: any;
                                responseCode: number;
                                bodyRaw: any;
                                "_202": any;
                                "_401": any;
                                "_403": any;
                                "_404": any;
                                "_409": any;
                                "_500": any;
                                "_503": any;
                            }>;
                        }
                        module TenantProductsProductIdMediaMediaIdCommit {
                        }
                    }
                }
            }
        }
    }
}
